import { DeclarationOption } from 'typedoc';
/**
 *
 * TypeDoc creates documentation according to exports. The structure will be driven by the implemented entryPoints config. https://typedoc.org/guides/options/#entrypointstrategy.
 *
 * This options aims to provide some flexibility as to how files can be generated.
 *
 * **`members`**
 *
 * Generates an individual file for each exported member. This is the standard behaviour of the HTML theme and the plugin default.
 *
 * It is also possible to further refine what members are exported to individual files with the [`--membersWithOwnFile`](#membersWithOwnFile) option.
 *
 * **`modules`**
 *
 * Generates a single file for every Module or Namespace where all members are hoisted to a single module file. This creates a flat navigation structure and reduces the amount of files generated.
 *
 * @category fileOutput
 */
export declare const outputFileStrategy: DeclarationOption;
/**
 * To export only Interfaces, classes and enums to their own file, the option should be configured in an options file as follows:
 *
 * ```js
 * {
 *   membersWithOwnFile: ['Interface', 'Class', 'Enum']
 * }
 * ```
 *
 * @category fileOutput
 */
export declare const membersWithOwnFile: DeclarationOption;
/**
 * The entry page in this context is the reference to the file that acts as a root page for the documentation, equivalent to `index.html` for web pages.
 *
 * `index.md` is the default, however `README.md` is recognised when browsing folders on repos and Wikis.
 *
 * The content of this file is one of the following:
 *
 * a) The [`--entryModule`](#--entrymodule) (if set).
 * b) The resolved Readme file.
 * c) The documentation index page (if readme = none).
 *
 * @category fileOutput
 *
 */
export declare const entryFileName: DeclarationOption;
/**
 * If set the name of the file will be determined by the value of [`--entryFileName`](#--entryfilename).
 *
 * This is only applicable when multiple modules are resolved.
 *
 * @category fileOutput
 */
export declare const entryModule: DeclarationOption;
/**
 * By default when a readme file is resolved, a seperate readme page is created. This option prepends the readme contents into the index page.
 * This option has no effect when `readme` is set to `none`.
 *
 * @category fileOutput
 *
 */
export declare const mergeReadme: DeclarationOption;
/**
 * @category ui
 */
export declare const hidePageHeader: DeclarationOption;
/**
 * @category ui
 */
export declare const hidePageTitle: DeclarationOption;
/**
 * @category ui
 */
export declare const hideBreadcrumbs: DeclarationOption;
/**
 * @category ui
 */
export declare const hideInPageTOC: DeclarationOption;
/**
 * Provides a mechanism to change the main project index page title.
 *
 * Defaults to `{projectName}` - a placeholder that renders the project name and version (when `--includeVersion` is set).
 *
 * @category ui
 */
export declare const indexPageTitle: DeclarationOption;
/**
 * Provides a mechanism to change the page title of members.
 *
 * Supports `{name}` and `{kind}` placeholders.
 *
 * e.g "Class: MyClassName"
 *
 * For example to display member name only:
 *
 * ```json
 * memberPageTitle: "{name}"
 * ```
 *
 * @category ui
 */
export declare const memberPageTitle: DeclarationOption;
/**
 * By default members are grouped by kind (eg Classes, Functions etc).
 *
 * This creates a flat structure where all members are displayed at the same heading level.
 *
 * @category ui
 */
export declare const excludeGroups: DeclarationOption;
/**
 * This option can be used to improve readability and aesthetics when defining signatures and declarations.
 *
 * Please note that when this option is set to `true` it is not possible to link to other references.
 *
 * As a work around the `{\@link}` tag can be be used to manually reference types.
 *
 * @category ui
 */
export declare const useCodeBlocks: DeclarationOption;
/**
 * By default objects inside declaration are collapsed to preserve space and improve readability.
 *
 * *Default example:*
 *
 * `object`
 *
 * *Expanded example:*
 *
 * { `x`: `string` }
 *
 * @category ui
 */
export declare const expandObjects: DeclarationOption;
/**
 * @category ui
 */
export declare const parametersFormat: DeclarationOption;
/**
 * @category ui
 */
export declare const propertiesFormat: DeclarationOption;
/**
 * @category ui
 */
export declare const enumMembersFormat: DeclarationOption;
/**
 * @category ui
 */
export declare const typeDeclarationFormat: DeclarationOption;
/**
 * This determines wheter to display index items either as a simple lists or in a table with a description column exposing the comment summary.
 *
 * @category ui
 */
export declare const indexFormat: DeclarationOption;
/**
 * @category other
 */
export declare const preserveAnchorCasing: DeclarationOption;
/**
 * @category other
 */
export declare const anchorPrefix: DeclarationOption;
/**
 *
 * Internal anchor links are used when referencing symbols with in-page table of contents or when referenced with  by {\@link} tags.
 *
 * There are two flags exposed by this option:
 *
 * - `headings` - Add HTML named anchors to heading for implementations that do not assign header ids.
 * - `tableRows` - Add anchors to table rows when table formats are selected and no heading elements are present.
 *
 * @category other
 */
export declare const namedAnchors: DeclarationOption;
/**
 * @category other
 */
export declare const publicPath: DeclarationOption;
