"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NavigationContext = void 0;
const typedoc_1 = require("typedoc");
const custom_maps_1 = require("../plugin/options/custom-maps");
class NavigationContext {
    constructor(theme, options) {
        this.theme = theme;
        this.options = options;
        this.navigation = [];
    }
    getNavigation(project) {
        var _a;
        const hasReadme = Boolean(project.readme);
        const containsOnlyModules = (_a = project === null || project === void 0 ? void 0 : project.children) === null || _a === void 0 ? void 0 : _a.every((child) => child.hasOwnDocument);
        if (hasReadme) {
            if (!containsOnlyModules &&
                this.options.outputFileStrategy === custom_maps_1.OutputFileStrategy.Members &&
                this.options.entryPointStrategy !== typedoc_1.EntryPointStrategy.Packages) {
                this.navigation.push({
                    title: 'Documentation',
                    url: project.url,
                });
            }
        }
        this.buildNavigationFromProject(project);
        return this.navigation;
    }
    buildNavigationFromProject(project) {
        var _a, _b, _c, _d;
        if ((_a = project.groups) === null || _a === void 0 ? void 0 : _a.length) {
            const entryModule = Boolean((_b = project === null || project === void 0 ? void 0 : project.groups[0]) === null || _b === void 0 ? void 0 : _b.children.find((child) => child.name === this.options.entryModule));
            if ((project.groups.length === 1 && !Boolean(entryModule)) ||
                (project.groups.length === 1 &&
                    this.options.outputFileStrategy === custom_maps_1.OutputFileStrategy.Modules)) {
                const children = this.getGroupChildren(project.groups[0]);
                if (children) {
                    this.navigation.push(...children.filter((child) => child.title !== this.options.entryModule));
                }
            }
            else {
                (_c = project.groups) === null || _c === void 0 ? void 0 : _c.forEach((projectGroup) => {
                    const children = this.getGroupChildren(projectGroup);
                    const indexModule = projectGroup.children.find((child) => child.name === this.options.entryModule);
                    if (children.length) {
                        this.navigation.push({
                            title: projectGroup.title,
                            children: children.filter((child) => child.title !== this.options.entryModule),
                        });
                    }
                    if (indexModule) {
                        const children = this.getChildrenOrGroups(indexModule);
                        if (children) {
                            this.navigation.push(...children);
                        }
                    }
                });
            }
        }
        else {
            (_d = project.children) === null || _d === void 0 ? void 0 : _d.forEach((child) => {
                this.navigation.push({
                    title: child.name,
                    children: this.getChildrenOrGroups(child) || [],
                    ...(child.url && { url: child.url }),
                });
            });
        }
    }
    getCategoryGroupChildren(group) {
        var _a;
        return (_a = group.children) === null || _a === void 0 ? void 0 : _a.filter((child) => child.hasOwnDocument).map((child) => {
            const children = this.getChildrenOrGroups(child);
            return {
                title: child.name,
                url: child.url,
                ...(children && { children }),
            };
        });
    }
    getGroupChildren(group) {
        var _a, _b, _c;
        if ((_a = group === null || group === void 0 ? void 0 : group.categories) === null || _a === void 0 ? void 0 : _a.length) {
            return (_b = group.categories) === null || _b === void 0 ? void 0 : _b.map((category) => {
                return {
                    title: category.title,
                    children: this.getCategoryGroupChildren(category),
                };
            });
        }
        return (_c = group.children) === null || _c === void 0 ? void 0 : _c.filter((child) => child.hasOwnDocument).map((child) => {
            var _a, _b;
            const mapping = this.theme.getTemplateMapping(child.kind);
            if (Boolean(mapping)) {
                const children = ((_a = child.categories) === null || _a === void 0 ? void 0 : _a.length)
                    ? (_b = child.categories) === null || _b === void 0 ? void 0 : _b.map((category) => {
                        const catChildren = this.getCategoryGroupChildren(category);
                        return catChildren.length
                            ? {
                                title: category.title,
                                children: catChildren,
                            }
                            : null;
                    }).filter((cat) => Boolean(cat))
                    : this.getChildrenOrGroups(child);
                return {
                    title: child.name,
                    url: child.url,
                    ...(children && { children }),
                };
            }
        });
    }
    getChildrenOrGroups(reflection) {
        var _a, _b, _c;
        if ((_a = reflection.groups) === null || _a === void 0 ? void 0 : _a.some((group) => group.allChildrenHaveOwnDocument())) {
            if (this.options.excludeGroups) {
                return (_b = reflection.children) === null || _b === void 0 ? void 0 : _b.filter((child) => child.hasOwnDocument).map((child) => {
                    const children = this.getChildrenOrGroups(child);
                    return {
                        title: child.name,
                        url: child.url,
                        ...(children && { children }),
                    };
                });
            }
            return (_c = reflection.groups) === null || _c === void 0 ? void 0 : _c.map((group) => {
                const groupChildren = this.getGroupChildren(group);
                return groupChildren.length
                    ? {
                        title: group.title,
                        children: this.getGroupChildren(group) || null,
                    }
                    : null;
            }).filter((group) => Boolean(group));
        }
        return null;
    }
}
exports.NavigationContext = NavigationContext;
