"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.header = void 0;
const typedoc_1 = require("typedoc");
const elements_1 = require("../../../support/elements");
const helpers_1 = require("../../helpers");
/**
 * @category Partials
 */
function header(context, page) {
    const isPackages = context.options.getValue('entryPointStrategy') ===
        typedoc_1.EntryPointStrategy.Packages;
    if (isPackages) {
        const packageItem = findPackage(page.model);
        if (packageItem) {
            return packageHeader(context, page);
        }
    }
    return projectHeader(context, page, isPackages);
}
exports.header = header;
function projectHeader(context, page, isPackages = false) {
    var _a, _b, _c, _d, _e;
    const entryFileName = context.options.getValue('entryFileName');
    const md = [];
    const readmeLabel = 'Readme';
    const documentationLabel = (0, helpers_1.getIndexLabel)(page.project, isPackages);
    md.push((0, elements_1.bold)(getProjectName(page.project, context, context.options.getValue('titleLink'))));
    md.push('•');
    const preserveReadme = Boolean(page.project.readme) && !context.options.getValue('mergeReadme');
    const isSinglePage = ((_a = page.project) === null || _a === void 0 ? void 0 : _a.groups) &&
        ((_b = page.project) === null || _b === void 0 ? void 0 : _b.groups.every((group) => !group.allChildrenHaveOwnDocument()));
    const preserveModulesPage = (((_c = page.project) === null || _c === void 0 ? void 0 : _c.groups) &&
        Boolean((_e = (_d = page.project) === null || _d === void 0 ? void 0 : _d.groups[0]) === null || _e === void 0 ? void 0 : _e.children.find((child) => child.name === context.options.getValue('entryModule')))) ||
        false;
    if (preserveReadme) {
        const links = [];
        links.push((0, elements_1.link)(readmeLabel, context.relativeURL(preserveModulesPage ? 'readme_.md' : entryFileName)));
        links.push('\\|');
        links.push((0, elements_1.link)(documentationLabel, context.relativeURL(page.project.url)));
        md.push(links.join(' '));
    }
    else {
        md.push(isSinglePage
            ? documentationLabel
            : (0, elements_1.link)(documentationLabel, preserveModulesPage
                ? context.relativeURL(page.project.url)
                : context.relativeURL(entryFileName)));
    }
    return `${md.join(' ')}\n\n***\n`;
}
function packageHeader(context, page) {
    const packageItem = findPackage(page.model);
    if (!packageItem) {
        return '';
    }
    const md = [];
    const readmeLabel = 'Readme';
    const documentationLabel = (0, helpers_1.getIndexLabel)(packageItem);
    const isSinglePage = (packageItem === null || packageItem === void 0 ? void 0 : packageItem.groups) &&
        (packageItem === null || packageItem === void 0 ? void 0 : packageItem.groups.every((group) => !group.allChildrenHaveOwnDocument()));
    const entryFileName = context.options.getValue('entryFileName');
    md.push(getProjectName(page.project, context, page.project.url));
    md.push('•');
    const packageItemName = packageItem.packageVersion
        ? `${packageItem.name} - v${packageItem.packageVersion}`
        : packageItem.name;
    md.push((0, elements_1.bold)(packageItemName));
    md.push('•');
    const preservePackageReadme = Boolean(packageItem.readme) && !context.options.getValue('mergeReadme');
    if (preservePackageReadme) {
        const links = [];
        const readmeUrl = `${packageItem.name}/${entryFileName}`;
        links.push((0, elements_1.link)(readmeLabel, context.relativeURL(readmeUrl)));
        links.push('\\|');
        links.push((0, elements_1.link)(documentationLabel, context.relativeURL(packageItem.url)));
        md.push(links.join(' '));
    }
    else {
        md.push(isSinglePage
            ? documentationLabel
            : (0, elements_1.link)(documentationLabel, context.relativeURL(packageItem.url)));
    }
    return `${md.join(' ')}\n\n***\n`;
}
function getProjectName(project, context, url) {
    const projectName = (0, helpers_1.getProjectDisplayName)(project, context.options.getValue('includeVersion'));
    if (url) {
        return (0, elements_1.link)(projectName, context.relativeURL(url));
    }
    else {
        return projectName;
    }
}
function findPackage(model) {
    var _a;
    if (model.kindOf(typedoc_1.ReflectionKind.Module) &&
        ((_a = model.parent) === null || _a === void 0 ? void 0 : _a.kindOf(typedoc_1.ReflectionKind.Project))) {
        return model;
    }
    if (model.parent) {
        return findPackage(model.parent);
    }
    return null;
}
