"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.declarationMember = void 0;
const typedoc_1 = require("typedoc");
const elements_1 = require("../../../support/elements");
/**
 * @category Partials
 */
function declarationMember(context, declaration, headingLevel, nested = false) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const md = [];
    md.push(context.declarationMemberIdentifier(declaration));
    if (declaration.comment) {
        md.push(context.comment(declaration.comment, headingLevel));
    }
    if (declaration.type instanceof typedoc_1.IntersectionType) {
        (_b = (_a = declaration.type) === null || _a === void 0 ? void 0 : _a.types) === null || _b === void 0 ? void 0 : _b.forEach((intersectionType) => {
            if (intersectionType instanceof typedoc_1.ReflectionType) {
                md.push((0, elements_1.heading)(headingLevel, 'Type declaration'));
                md.push(context.typeDeclarationMember(intersectionType.declaration, headingLevel));
            }
        });
    }
    if (declaration.type instanceof typedoc_1.ReferenceType &&
        ((_c = declaration.type.typeArguments) === null || _c === void 0 ? void 0 : _c.length)) {
        if (declaration.type.typeArguments[0] instanceof typedoc_1.ReflectionType) {
            md.push((0, elements_1.heading)(headingLevel, 'Type declaration'));
            md.push(context.typeDeclarationMember(declaration.type.typeArguments[0].declaration, headingLevel));
        }
    }
    if (declaration.typeParameters) {
        md.push((0, elements_1.heading)(headingLevel, 'Type parameters'));
        if (context.options.getValue('parametersFormat') === 'table') {
            md.push(context.typeParametersTable(declaration.typeParameters));
        }
        else {
            md.push(context.typeParametersList(declaration.typeParameters, headingLevel + 1));
        }
    }
    const typeDeclaration = (_d = declaration.type) === null || _d === void 0 ? void 0 : _d.declaration;
    if (typeDeclaration) {
        if (typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.indexSignature) {
            md.push((0, elements_1.heading)(headingLevel, `Index signature`));
            md.push(context.indexSignatureTitle(typeDeclaration.indexSignature));
        }
        if (((_e = typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.signatures) === null || _e === void 0 ? void 0 : _e.length) ||
            ((_f = typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.children) === null || _f === void 0 ? void 0 : _f.length)) {
            if ((_g = typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.signatures) === null || _g === void 0 ? void 0 : _g.length) {
                typeDeclaration.signatures.forEach((signature) => {
                    md.push(context.signatureMember(signature, headingLevel, true));
                });
            }
            if (!nested && ((_h = typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.children) === null || _h === void 0 ? void 0 : _h.length)) {
                md.push((0, elements_1.heading)(headingLevel, 'Type declaration'));
                md.push(context.typeDeclarationMember(typeDeclaration, headingLevel));
            }
        }
    }
    md.push(context.inheritance(declaration, headingLevel));
    if (!nested && declaration.sources) {
        md.push(context.sources(declaration, headingLevel));
    }
    return md.join('\n\n');
}
exports.declarationMember = declarationMember;
