"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.propertiesTable = void 0;
const elements_1 = require("../../../support/elements");
const utils_1 = require("../../../support/utils");
const helpers_1 = require("../../helpers");
/**
 * @category Partials
 */
function propertiesTable(context, props) {
    const modifiers = props.map((param) => (0, helpers_1.getModifier)(param));
    const hasModifiers = modifiers.some((value) => Boolean(value));
    const inheritance = props.map((reflection) => Boolean(reflection.overwrites) || Boolean(reflection.inheritedFrom));
    const hasInheritance = inheritance.some((value) => Boolean(value));
    const hasSources = !context.options.getValue('disableSources');
    const headers = [];
    if (hasModifiers) {
        headers.push('Modifier');
    }
    headers.push('Property');
    headers.push('Type');
    headers.push('Description');
    if (hasInheritance) {
        headers.push('Inheritance');
    }
    if (hasSources) {
        headers.push('Source');
    }
    const rows = [];
    const declarations = (0, helpers_1.flattenDeclarations)(props);
    declarations.forEach((property, index) => {
        var _a;
        const propertyType = (0, helpers_1.getDeclarationType)(property);
        const row = [];
        if (hasModifiers) {
            row.push((0, elements_1.backTicks)(modifiers[index] || 'public'));
        }
        const nameColumn = [];
        if (((_a = context.options.getValue('namedAnchors')) === null || _a === void 0 ? void 0 : _a.tableRows) &&
            property.anchor) {
            nameColumn.push(`<a id="${property.anchor}" name="${property.anchor}"></a>`);
        }
        const propertyName = `${property.name}${property.flags.isOptional ? '?' : ''}`;
        if (property.isDeprecated && property.isDeprecated()) {
            nameColumn.push((0, elements_1.strikeThrough)((0, elements_1.backTicks)(propertyName)));
        }
        else {
            nameColumn.push((0, elements_1.backTicks)(propertyName));
        }
        row.push(nameColumn.join(' '));
        if (propertyType) {
            row.push((0, utils_1.stripLineBreaks)(context.someType(propertyType), false));
        }
        const comments = property.comment;
        if (comments) {
            row.push((0, utils_1.stripLineBreaks)((0, utils_1.formatTableDescriptionCol)(context.comment(comments))));
        }
        else {
            row.push('-');
        }
        if (hasInheritance) {
            row.push(context.inheritance(property, -1) || '-');
        }
        if (hasSources) {
            row.push(context.sources(property, -1));
        }
        rows.push(row);
    });
    return (0, elements_1.table)(headers, rows);
}
exports.propertiesTable = propertiesTable;
