import { DeclarationReflection, PageEvent, ProjectReflection, Reflection, ReflectionKind, RenderTemplate, Renderer, Theme } from 'typedoc';
import { MarkdownPageEvent } from '../plugin/events';
import { OutputFileStrategy } from '../plugin/options/custom-maps';
import { UrlMapping } from '../plugin/url-mapping';
import { NavigationItem, TemplateMapping } from './models';
import { NavigationContext } from './navigation-context';
import { MarkdownThemeRenderContext } from './render-context';
import { UrlsContext } from './urls-context';
/**
 * This is in-built MarkdownTheme which extends TypeDocs Theme class.
 * This follows the implementation of TypeDoc's [DefaultTheme](https://typedoc.org/api/classes/DefaultThemeRender.html).
 *
 * The {@link render } and {@link getUrls} methods is where the work happens.
 */
export declare class MarkdownTheme extends Theme {
    /**
     *
     * @param renderer The TypeDoc renderer instance the theme is attached to.
     */
    constructor(renderer: Renderer);
    getRenderContext(pageEvent: MarkdownPageEvent<Reflection> | null): MarkdownThemeRenderContext;
    getNavigationContext(): NavigationContext;
    getUrlsContext(project: ProjectReflection): UrlsContext;
    readmeTemplate: (pageEvent: MarkdownPageEvent<ProjectReflection>) => string;
    projectTemplate: (pageEvent: MarkdownPageEvent<ProjectReflection>) => string;
    reflectionTemplate: (pageEvent: MarkdownPageEvent<DeclarationReflection>) => string;
    memberTemplate: (pageEvent: MarkdownPageEvent<DeclarationReflection>) => string;
    /**
     * Renders a template and page model to a string.
     */
    render(page: MarkdownPageEvent<Reflection>, template: RenderTemplate<MarkdownPageEvent<Reflection>>): string;
    getUrls(project: ProjectReflection): UrlMapping[];
    getNavigation(project: ProjectReflection): NavigationItem[];
    hasToc(page: PageEvent): boolean | undefined;
    insertToc(page: PageEvent, contents: string): string;
    /**
     * Returns the template mapping for a given reflection kind
     * @param kind
     */
    getTemplateMapping(kind: ReflectionKind, outputFileStrategyOverride?: OutputFileStrategy): TemplateMapping;
}
